pub struct CalendarSourceConfig {
pub source: String,
pub name: String,
pub title: Option<String>,
pub cookies: Option<Vec<String>>,
/* private fields */
}Expand description
A Config item representing a calendar source
Fields
source: StringThe url or file path of the calendar
NOTE: File paths are relative to the config file
name: StringThe name or internal identifier of the calendar
Because this is to be used internally, there are a few restrictions
- No spaces
- Dash separated a.k.a. kebab-case
- Must be unique per config file
title: Option<String>The user facing title for the calendar
This will be pulled from the calendar if it contains a X-WR-CALNAME property.
If you provide a title here, it will override any calendar provided title.
An array of headers to pass along with the main request
This is handy if you are retrieving calendars from a site which requires login. Cookie values and other necessary headers can be provided so the request can succeed.
For example, meetup.com requires a header like the following:
MEETUP_MEMBER=id=<IDENTIFIER>&s=<SESSION_TOKEN>We may add the ability to auto-retrieve cookies from a local browser at some point.